pub struct GenericSender<T: Serialize>(GenericSenderVariants<T>);Expand description
A GenericSender that sends messages to a GenericReceiver.
The sender supports sending messages cross-process, if servo is run in multiprocess mode.
Tuple Fields
0: GenericSenderVariants<T>Implementations
Sourceimpl<T: Serialize> GenericSender<T>
impl<T: Serialize> GenericSender<T>
pub fn send(&self, msg: T) -> SendResult
Sourcepub fn send_or_warn(&self, msg: T)
pub fn send_or_warn(&self, msg: T)
Send a message T and log any error (instead of returning it).
In cases where channel closure is possible (because the receiver does not exist anymore), this convenience method can be used to ignore the result and log the error as a warning.
Sourcepub fn send_or_ignore(&self, msg: T)
pub fn send_or_ignore(&self, msg: T)
Send a message T and ignore the result
In cases where channel closure is expected to happen intermittently, and the sender
doesn’t care about the result, this is a short form for let _ = GenericSender::send();,
which makes the intent clearer.